@@ -1,7 +1,6 @@
-pub use async_lock::Mutex;
-pub use async_lock::RwLock;
-pub use canary;
+
 use canary::Channel;
+
 pub use srpc_macro::*;
 
 pub trait Peer {
@@ -23,4 +22,14 @@ pub mod __private {
     pub use serde::Deserialize;
     pub use serde::Serialize;
     pub use serde_repr::*;
+
+    pub use async_lock::Mutex;
+    pub use async_lock::RwLock;
+    pub use canary;
+}
+
+pub mod prelude {
+    pub use crate::IntoClient;
+    pub use crate::Peer;
+    pub use srpc_macro::*;
 }
